@@ -135,7 +135,7 @@ void emu_setDefaultConfig(void)
 	memset(&currentConfig, 0, sizeof(currentConfig));
 	currentConfig.lastRomFile[0] = 0;
 	currentConfig.EmuOpt  = 0x1f | 0x600; // | confirm_save, cd_leds
-	currentConfig.PicoOpt = 0x0f | 0x20 | 0xe00; // | use_940, cd_pcm, cd_cdda
+	currentConfig.PicoOpt = 0x0f | 0x20 | 0xe00 | 0x1000; // | use_940, cd_pcm, cd_cdda, scale/rot
 	currentConfig.PsndRate = 22050; // 44100;
 	currentConfig.PicoRegion = 0; // auto
 	currentConfig.PicoAutoRgnOrder = 0x184; // US, EU, JP
@@ -579,7 +579,7 @@ void emu_Loop(void)
 		frames_done++; frames_shown++;
 	}
 
-	change_fast_forward(0);
+	//change_fast_forward(0);
 
 	if (PicoMCD & 1) PicoCDBufferFree();
 /*
