@@ -51,23 +51,27 @@ static struct {
 } music_request;
 
 static inline void check_music() {
-	int cd_on = ((PicoMCD & 1) && (PicoOpt & 0x800) && !(Pico_mcd->s68k_regs[0x36] & 1) && (Pico_mcd->scd.Status_CDC & 1));
+#if PLATFORM == FREMANTLE
+	int cd_on = ((PicoMCD & 1) && (PicoOpt & 0x800) && !(Pico_mcd->s68k_regs[0x36] & 1) && (Pico_mcd->scd.Status_CDC & 1) && (currentConfig.EmuOpt & 0x04));
 	if( !cd_on ) {
-		if( music_request.playing ) gst_element_set_state( pipeline, GST_STATE_NULL );
+		if( music_request.playing ) {
+			gst_element_set_state( pipeline, GST_STATE_NULL );
+			music_request.playing = 0;
+		}
 	}
-	else if( music_request.request || !music_request.playing ) {
-		printf( "Playing CD Track: [%s], seek: %d\n", music_request.file, music_request.seek );
-		gst_element_set_state( pipeline, GST_STATE_NULL );
-		if( music_request.file && music_request.seek >= 0 ) {
-			GstElement* filesrc = gst_bin_get_by_name( GST_BIN(pipeline), "mp3file" );
-			if( !filesrc ) printf( "Error tope de gordo: Falta filesrc\n" );
-			g_object_set( G_OBJECT(filesrc), "location", music_request.file, NULL );
-			gst_element_set_state( pipeline, GST_STATE_PLAYING );
-			if( music_request.seek ) gst_element_seek( pipeline, 1.0, GST_FORMAT_TIME, GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET, music_request.seek, GST_SEEK_TYPE_NONE, GST_CLOCK_TIME_NONE );
-			music_request.playing = 1;
-		} else music_request.playing = 0;
+	else if( music_request.file && music_request.request ) {
+		music_request.playing = 1;
 		music_request.request = 0;
+		gst_element_set_state( pipeline, GST_STATE_NULL );
+		GstElement* filesrc = gst_bin_get_by_name( GST_BIN(pipeline), "mp3file" );
+		g_object_set( G_OBJECT(filesrc), "location", music_request.file, NULL );
+		gst_element_set_state( pipeline, GST_STATE_PAUSED );
+		SDL_Delay(10);
+		if( music_request.seek > 0 )
+			gst_element_seek_simple( pipeline, GST_FORMAT_TIME, GST_SEEK_FLAG_FLUSH, music_request.seek );
+		gst_element_set_state( pipeline, GST_STATE_PLAYING );
 	}
+#endif
 }
 
 static void sdl_key( int key, int press ) {
@@ -308,12 +312,28 @@ unsigned long maemo_joystick_read(int allow_usb_joy)
 int mp3_get_offset() {
 	gint64 pos;
 	GstFormat fmt = GST_FORMAT_TIME;
-	if( !music_request.playing ) return 0;
+	if( !music_request.file ) {
+		return 0;
+	}
+	GstState state;
+	gst_element_get_state( pipeline, &state, NULL, GST_CLOCK_TIME_NONE );
+	if( state != GST_STATE_PLAYING ) {
+		return 0;
+	}
 	gst_element_query_position( pipeline, &fmt, &pos );
-	return pos / 1000000;
+	pos /= (gint64)1000000;
+	return pos;
 }
 
 void mp3_start_play( char* file, int seek ) {
+	//printf( "START PLAY: %d %s\n", seek, file );
+	if( seek < 0 ) {
+		//if( music_request.file == file ) return;
+		seek = 0;
+	}
+	FILE *f = fopen( "/home/user/.picodrive/picodrive.log", "a" );
+	fprintf( f, "Loading offset: %d\n", seek );
+	fclose(f);
 	music_request.file = file;
 	music_request.seek = (gint64)seek * (gint64)1000000;
 	music_request.request = 1;
@@ -425,17 +445,17 @@ void maemo_init(void)
 	SDL_OpenAudio( &as, NULL );
 	SDL_PauseAudio(0);
 
+#if PLATFORM == FREMANTLE
 	// Init CD music
     GError* error;
-	pipeline = gst_parse_launch( "filesrc name=mp3file location=null ! mp3parse ! nokiamp3dec ! pulsesink", &error );
+    pipeline = gst_parse_launch( "filesrc name=mp3file location=null ! mp3parse ! nokiamp3dec ! pulsesink", &error );
 	if( !pipeline ) printf( "Cannot initialize gstreamer\n" );
-	if( error ) {
-		printf( "Error creating pipeline: %s\n", error->message );
-	}
+	if( error ) printf( "Error initializing pipeline: %s\n", error->message );
 	GstElement* filesrc = gst_bin_get_by_name( GST_BIN(pipeline), "mp3file" );
-	if( !filesrc ) printf( "Pipeline parse error: missing filesrc\n" );
-	g_object_set( G_OBJECT(filesrc), "location", "null", NULL );
+	g_object_set( G_OBJECT(filesrc), "location", NULL, NULL );
+
 	memset( &music_request, 0, sizeof(music_request) );
+#endif
 
 	// Init input
 	keystates = mousestates = accelstates = 0;
@@ -453,8 +473,10 @@ void maemo_deinit(void)
 	running = 0;
 	pthread_join( sdl_thread, NULL );
 
+#if PLATFORM == FREMANTLE
 	gst_element_set_state( pipeline, GST_STATE_NULL );
 	gst_object_unref( GST_OBJECT(pipeline) );
+#endif
 
 	SDL_PauseAudio(1);
 	SDL_CloseAudio();
