@@ -52,6 +52,11 @@ void cli_config( char* file ) {
 		return;
 	}
 	printf( "Reading config file %s\n", file );
+
+	currentConfig.screensaver = 0;
+	currentConfig.player[0].inputFlags = _P_ENABLE_KEY;
+	currentConfig.player[1].inputFlags = _P_ENABLE_KEY;
+
 	char opt[64], value[64];
 	unsigned short* key_map = currentConfig.player[0].keymap;
 	unsigned short* key_map2 = currentConfig.player[1].keymap;
@@ -106,9 +111,9 @@ void cli_config( char* file ) {
 		else if( !strcmp( opt, "FRAMESKIP" ) ) currentConfig.Frameskip = atoi(value);
 		else if( !strcmp( opt, "DISPLAY_FRAMERATE" ) ) { if( atoi(value) ) currentConfig.EmuOpt |= 0x02; else currentConfig.EmuOpt &= ~0x02; }
 		else if( !strcmp( opt, "SOUND" ) ) { if( atoi(value) ) currentConfig.EmuOpt |= 0x04; else currentConfig.EmuOpt &= ~0x04; }
+		else if( !strcmp( opt, "P1_TS_ENABLE") ) { if( atoi(value) ) currentConfig.player[0].inputFlags |= _P_ENABLE_TS; }
+		else if( !strcmp( opt, "P2_TS_ENABLE") ) { if( atoi(value) ) currentConfig.player[1].inputFlags |= _P_ENABLE_TS; }
 	}
-	currentConfig.screensaver = 0;
-	currentConfig.player[0].inputFlags = _P_ENABLE_KEY | _P_ENABLE_TS;
 }
 
 void parse_cmd_line(int argc, char *argv[])
